@@ -12,16 +12,18 @@ require Type::Tiny;
 our $CALLER   = caller;
 our @DEFAULTS = 'Types::Standard';
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 unshift @Function::Parameters::type_reifiers => sub {
     Type::Registry->for_class($CALLER)->lookup($_[0]);
 };
 
 sub import {
-    my @ARGUMENTS = map 'ARRAY' eq ref $_ ? @$_ : $_, splice @_, 1;
-    my @LIBRARIES = grep { !ref && !/^:/ } @ARGUMENTS;
-    my @CONFIG    = grep { ref  ||  /^:/ } @ARGUMENTS;
+    my (@CONFIG, @LIBRARIES);
+    for (map 'ARRAY' eq ref $_ ? @$_ : $_, splice @_, 1) {
+        push @LIBRARIES, $_ and next if !ref && !/^:/;
+        push @CONFIG,    $_;
+    }
     Type::Registry->for_class($CALLER)->add_types($_) for @DEFAULTS, @LIBRARIES;
     Function::Parameters->import(@CONFIG);
 }
@@ -40,7 +42,7 @@ Type::Tiny::Signatures - Method/Function Signatures w/Type::Tiny Constraints
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
